@@ -10,9 +10,8 @@ config = {
     "handlers": [
         {
             "sink": sys.stdout,
-            "format": "<green>{time:HH:mm:ss}</green>|<level>{level: ^7}</level>| {message}",
+            "format": "|<level>{level: ^7}</level>| {message}",
         },
     ],
-    "extra": {"user": "someone"},
 }
 logger.configure(**config)
