@@ -34,10 +34,10 @@ from typing import Optional
 from typing import Tuple
 
 import requests
+from humanize import naturalsize
 from loguru import logger
 from ruamel.yaml import YAML
 
-
 # Configuration access to Cyber Range endpoint
 CORE_API_URL = "http://127.0.0.1:5000"
 # Expect a path to CA certs (see:
@@ -328,8 +328,10 @@ def create_simulation_from_topology(
     return id_simulation
 
 
-def create_simulation_from_basebox(basebox_id: str) -> int:
-    """Create a new simulation model in database based on the provided basebox id."""
+def create_simulation_from_basebox(
+    basebox_id: str, add_internet: bool = False, add_host: bool = False
+) -> int:
+    """Create a new simulation model in database based on the provided basebox id, with optionnaly internet and/or host connectivity."""
 
     if basebox_id is None:
         raise Exception("A basebox ID is required")
@@ -349,6 +351,11 @@ def create_simulation_from_basebox(basebox_id: str) -> int:
     yaml_content = f"""---
 name: "{basebox_id}"
 nodes:
+
+  - &switch
+    type: switch
+    name: "switch"
+
   - &client
     type: virtual_machine
     name: "client"
@@ -356,21 +363,24 @@ nodes:
     nb_proc: {nb_proc}
     memory_size: {memory_size}
     roles: ["{role}"]
+"""
 
+    if add_host:
+        yaml_content += """
   - &host_machine
     type: host_machine
     name: "host_machine"
+"""
 
+    if add_internet:
+        # add default route to gateway, a gateway and a switch to plug the gateway and the router
+        yaml_content += """
   - &router
     type: router
     name: "router"
     routes:
       - "0.0.0.0/0 -> 192.168.23.2"
 
-  - &switch
-    type: switch
-    name: "switch"
-
   - &switch_internet
     type: switch
     name: "switch_internet"
@@ -378,8 +388,17 @@ nodes:
   - &physical_gateway
     type: physical_gateway
     name: "physical_gateway"
+"""
+    else:
+        yaml_content += """
+  - &router
+    type: router
+    name: "router"
+"""
 
+    yaml_content += """
 links:
+
   - switch: *switch
     node: *router
     params:
@@ -390,12 +409,18 @@ links:
     node: *client
     params:
       ip: "192.168.2.2/24"
+"""
 
+    if add_host:
+        yaml_content += """
   - switch: *switch
     node: *host_machine
     params:
       ip: "192.168.2.3/24"
+"""
 
+    if add_internet:
+        yaml_content += """
   - switch: *switch_internet
     node: *router
     params:
@@ -764,6 +789,83 @@ def update_node(node_id: int, node_dict: dict) -> Any:
     return result.json()
 
 
+def get_node_statistics_by_id(id_node: int) -> Any:
+    """
+    Return aggregated statistics from CPU, memory, block devices and network interfaces.
+    """
+    result = _get(f"/node/{id_node}/stats")
+
+    if result.status_code != 200:
+        _handle_error(result, "Cannot retrieve node statistics")
+
+    return result.json()
+
+
+def node_memorydump(id_node: int) -> Any:
+    """
+    Return RAM dump of a node in a running simulation
+    """
+    file_path_key = "file_path"
+    file_size_key = "file_size"
+    status_key = "status"
+
+    result = _get(f"/node/{id_node}/memorydump")
+
+    if (
+        result.status_code != 200
+        or status_key not in result.json()
+        or result.json()[status_key] != "STARTED"
+    ):
+        _handle_error(result, "Cannot initiate node memory dump fom core API")
+
+    logger.info("[+] Initialized memory dump of node '{}'...".format(id_node))
+
+    # Wait for the operation to be completed in backend
+    # Note : loop inspired from _simulation_execute_operation
+    while True:
+        # Sleep before next iteration
+        time.sleep(2)
+
+        # Fetch the current status of the memdump
+        result = _get(f"/node/{id_node}/memorydump_status")
+
+        if result.status_code != 200:
+            _handle_error(result, "Cannot get status of node memory dump fom core API")
+
+        result_json = result.json()
+        if not (
+            all(k in result_json for k in (file_path_key, file_size_key, status_key))
+        ):
+            raise Exception(
+                f"Contents of memory dump status update is not in the expected format (attributes '{file_path_key}', '{file_size_key}' and '{status_key}' expected)"
+            )
+
+        # Log info on progression
+        if result_json[status_key] == "PROGRESS":
+            logger.info(
+                "  [+] Currently performing memory dump of node '{}' (current dump file size is {})...".format(
+                    id_node, naturalsize(result_json[file_size_key], binary=True)
+                )
+            )
+        elif result_json[status_key] == "SUCCESS":
+            break
+        else:
+            raise Exception(
+                "Error during memory dump of node {} operation: '{}'".format(
+                    id_node, result_json[status_key]
+                )
+            )
+
+    logger.info(
+        "[+] Node memory dump (raw dump with libvirt) obtained, and placed in file {} ({}) on the server.".format(
+            result_json[file_path_key],
+            naturalsize(result_json[file_size_key], binary=True),
+        )
+    )
+
+    return result_json[file_path_key], result_json[file_size_key]
+
+
 def fetch_node_network_interfaces(id_node: int) -> Any:
     """Return network interfaces list given a node ID."""
     result = _get(f"/node/{id_node}/network_interface")
