@@ -24,6 +24,7 @@
 # PYTHON_ARGCOMPLETE_OK
 import argparse
 import configparser
+import json
 import os
 import shutil
 import sys
@@ -50,7 +51,6 @@ import cr_api_client.provisioning_api as provisioning_api
 import cr_api_client.redteam_api as redteam_api
 import cr_api_client.scenario_api as scenario_api
 
-
 # Initialize colorama
 if HAS_COLOUR:
     init(autoreset=True)
@@ -352,6 +352,26 @@ def simu_create_handler(args: Any) -> None:
     topology_file = args.topology_file
     basebox_id = args.basebox_id
     topology_resources_paths = args.topology_resources_paths
+    add_internet = args.add_internet
+    add_host = args.add_host
+
+    # Sanity checks
+    if topology_file is not None and basebox_id is not None:
+        raise Exception(
+            "Either a topology (-t) or a basebox ID (-b) is required to create a new simulation, but not both options"
+        )
+    if topology_file is not None:
+        if add_internet:
+            raise Exception("--add-internet is only available with -b option")
+        if add_host:
+            raise Exception("--add-host is only available with -b option")
+    elif basebox_id is not None:
+        if topology_resources_paths:
+            raise Exception("-r <resource_path> is only available with -t option")
+    else:
+        raise Exception(
+            "Either a topology (-t) or a basebox ID (-b) is required to create a new simulation"
+        )
 
     # Compute elpased time
     t1 = time.time()
@@ -364,11 +384,7 @@ def simu_create_handler(args: Any) -> None:
             )
         elif basebox_id is not None:
             id_simulation = core_api.create_simulation_from_basebox(
-                basebox_id=basebox_id
-            )
-        else:
-            raise Exception(
-                "Either a topology or a basebox ID is required to create a new simulation"
+                basebox_id=basebox_id, add_internet=add_internet, add_host=add_host
             )
 
         logger.info("[+] Created simulation ID: '{}'".format(id_simulation))
@@ -582,6 +598,8 @@ def scenario_play_handler(args: Any) -> None:
     file_results = args.scenario_file_results
     debug_mode = args.scenario_debug_mode
     speed = args.scenario_speed
+    record_video = args.scenario_record_video
+    write_logfile = args.scenario_write_logfile
 
     logger.info(
         "[+] Playing scenario '{}' on simulation id '{}'".format(
@@ -591,7 +609,13 @@ def scenario_play_handler(args: Any) -> None:
 
     try:
         scenario_api.scenario_play(
-            id_simulation, scenario_path, debug_mode, speed, file_results
+            id_simulation=id_simulation,
+            scenario_path=scenario_path,
+            debug_mode=debug_mode,
+            speed=speed,
+            record_video=record_video,
+            write_logfile=write_logfile,
+            scenario_file_results=file_results,
         )
     except Exception as e:
         logger.info(f"Error when playing scenario: '{e}'")
@@ -891,6 +915,44 @@ def simu_untap_handler(args: Any) -> None:
         logger.info("Stop redirection of network traffic to the tap interface")
 
 
+#
+# 'node_stats' simulation
+#
+def node_stats_handler(args: Any) -> None:
+    try:
+        if hasattr(args, "id_node"):
+            response = core_api.get_node_statistics_by_id(args.id_node)
+        else:
+            raise AttributeError(
+                "Unknown arguments for node_stats command: {}".format(args)
+            )
+
+    except Exception as e:
+        logger.info(f"Error when getting statistics on simulation: '{e}'")
+        sys.exit(1)
+
+    stats = json.loads(response)
+    logger.debug("Statistics on simulation gathered")
+    print(json.dumps(stats))
+
+
+#
+# 'node_memorydump' simulation
+#
+def node_memorydump_handler(args: Any) -> None:
+    try:
+        if hasattr(args, "id_node"):
+            file_path, file_size = core_api.node_memorydump(args.id_node)
+        else:
+            raise AttributeError(
+                "Unknown arguments for node_memorydump command: {}".format(args)
+            )
+
+    except Exception as e:
+        logger.error(e.__str__())
+        sys.exit(1)
+
+
 #
 # 'simu_delete' simulation
 #
@@ -1252,6 +1314,18 @@ def main() -> None:
         dest="basebox_id",
         help="Basebox ID with which to create a simulation",
     )
+    parser_simu_create.add_argument(
+        "--add-internet",
+        action="store_true",
+        dest="add_internet",
+        help="Add internet connectivity (only available with -b option)",
+    )
+    parser_simu_create.add_argument(
+        "--add-host",
+        action="store_true",
+        dest="add_host",
+        help="Add host connectivity (only available with -b option)",
+    )
     parser_simu_create.add_argument(
         "-r",
         action="store",
@@ -1372,6 +1446,22 @@ def main() -> None:
     parser_simu_untap.add_argument("id_simulation", type=int, help="The simulation id")
     parser_simu_untap.add_argument("iface", type=str, help="The tap network interface")
 
+    # 'node_stats' simulation command
+    parser_node_stats = subparsers.add_parser(
+        "node_stats",
+        help="Get resource statistics of a node",
+    )
+    parser_node_stats.set_defaults(func=node_stats_handler)
+    parser_node_stats.add_argument("id_node", type=int, help="The node unique id")
+
+    # 'node_memorydump' simulation command
+    parser_node_nmemorydump = subparsers.add_parser(
+        "node_memorydump",
+        help="Get the full raw memory dump of a node's RAM",
+    )
+    parser_node_nmemorydump.set_defaults(func=node_memorydump_handler)
+    parser_node_nmemorydump.add_argument("id_node", type=int, help="The node unique id")
+
     # --------------------
     # --- Topology options
     # --------------------
@@ -1683,6 +1773,20 @@ def main() -> None:
         default="normal",
         help="scenario speed ('slow', 'normal', 'fast')",
     )
+    parser_scenario_play.add_argument(
+        "--record-video",
+        action="store_true",
+        default=False,
+        dest="scenario_record_video",
+        help="record video of the play. For debug purpose only",
+    )
+    parser_scenario_play.add_argument(
+        "--write-logfile",
+        action="store_true",
+        default=False,
+        dest="scenario_write_logfile",
+        help="write logging messages of the play in a file. For debug purpose only",
+    )
 
     # 'scenario_status' command
     parser_scenario_status = subparsers.add_parser(
