@@ -127,18 +127,21 @@ def scenario_play(
     scenario_path: str,
     debug_mode: str = "off",
     speed: str = "normal",
+    record_video: bool = False,
+    write_logfile: bool = False,
     scenario_file_results: str = None,
 ) -> None:
     """Play scenario on targeted simulation."""
 
     scenario_success = False
-    scenario_log_filename = None
 
     try:
         data = {
             "idSimulation": id_simulation,
             "debug_mode": debug_mode,
             "speed": speed,
+            "record_video": record_video,
+            "write_logfile": write_logfile,
         }
 
         with TemporaryDirectory() as temp_dir:
@@ -188,9 +191,8 @@ def scenario_play(
 
         result = request.json()
 
-        scenario_results = result["result"][0]
+        scenario_results = result["result"]
         scenario_success = scenario_results["success"]
-        scenario_log_filename = result["result"][1]
 
         if scenario_success:
             logger.info(
@@ -200,10 +202,8 @@ def scenario_play(
             logger.error(
                 f"[-] Scenario was executed with errors on simulation ID '{id_simulation}'"
             )
-            if scenario_file_results is None:
-                logger.error(
-                    "[-] In order to know about errors, replay the scenario using the '-o <output_json_filename>' option"
-                )
+
+        logger.info(json.dumps(scenario_results, indent=4))
 
         if scenario_file_results is not None:
             # create file for json results
@@ -226,7 +226,7 @@ def scenario_play(
     except Exception as e:
         raise Exception("Issue when starting scenario execution: '{}'".format(e))
 
-    return (scenario_success, scenario_log_filename)
+    return scenario_success
 
 
 def scenario_status(id_simulation: int) -> None:
